==> odoo_19.2a1.20260202.zip: odoo-19.2a1.post20260202/odoo/addons/im_livechat/static/tests/tours/looking_for_help_discuss_category_tour.js <==
import { registry } from "@web/core/registry";

registry.category("web_tour.tours").add("im_livechat.looking_for_help_discuss_category_tour", {
    steps: () => [
        {
            // Two live chats are looking for help, they are both in the "Looking for help" category.
            trigger:
                ".o-mail-DiscussSidebarCategory-livechatNeedHelp + .o-mail-DiscussSidebarCategory-channels .o-mail-DiscussSidebarChannel-container:contains(Visitor Accounting) + .o-mail-DiscussSidebarChannel-container:contains(Visitor Sales)",
        },
        {
            trigger: ".o-mail-DiscussSidebarChannel:contains(Sales) .o-mail-starred",
        },
        {
            trigger:
                ".o-mail-DiscussSidebarChannel:contains(Visitor Accounting):contains(Invoice SO0042 not received)",
        },
        {
            trigger:
                ".o-mail-DiscussSidebarChannel:contains(Visitor Sales):contains(Delivery delayed for PO0099)",
        },
        {
            trigger:
                ".o-mail-DiscussSidebarChannel:contains(Accounting):not(:has(.o-mail-starred))",
        },
        {
            trigger: ".o-mail-DiscussSidebarChannel:contains(Accounting)",
            run: "hover && click [title='Chat Actions']",
        },
        {
            trigger:
                ".o-mail-DiscussSidebar:has(.o-mail-DiscussSidebarChannel:contains(Accounting))",
        },
        {
            trigger: "button[name='livechat-status']",
            run: "hover",
        },
        {
            trigger: ".o-livechat-LivechatStatusSelection-Label:contains(In progress)",
            run: "click",
        },
        {
            trigger:
                ".o-mail-DiscussSidebar:not(:has(.o-mail-DiscussSidebarChannel:contains(Accounting)))",
        },
    ],
});

==> odoo_19.3a1.20260226.zip: odoo-19.3a1.post20260226/odoo/addons/im_livechat/static/tests/tours/looking_for_help_discuss_category_tour.js <==
import { registry } from "@web/core/registry";

registry.category("web_tour.tours").add("im_livechat.looking_for_help_discuss_category_tour", {
    steps: () => [
        {
            // Two live chats are looking for help, they are both in the "Looking for help" category.
            trigger:
                ".o-mail-DiscussSidebarCategory-livechatNeedHelp + .o-mail-DiscussSidebarCategory-channels .o-mail-DiscussSidebarChannel-container:contains(Visitor Accounting) + .o-mail-DiscussSidebarChannel-container:contains(Visitor Sales)",
        },
        {
            trigger: ".o-mail-DiscussSidebarChannel:contains(Sales) .o-mail-favorite",
        },
        {
            trigger:
                ".o-mail-DiscussSidebarChannel:contains(Visitor Accounting):contains(Invoice SO0042 not received)",
        },
        {
            trigger:
                ".o-mail-DiscussSidebarChannel:contains(Visitor Sales):contains(Delivery delayed for PO0099)",
        },
        {
            trigger:
                ".o-mail-DiscussSidebarChannel:contains(Accounting):not(:has(.o-mail-favorite))",
        },
        {
            trigger: ".o-mail-DiscussSidebarChannel:contains(Accounting)",
            run: "hover && click [title='Chat Actions']",
        },
        {
            trigger:
                ".o-mail-DiscussSidebar:has(.o-mail-DiscussSidebarChannel:contains(Accounting))",
        },
        {
            trigger: "button[name='livechat-status']",
            run: "hover",
        },
        {
            trigger: ".o-livechat-LivechatStatusSelection-Label:contains(In progress)",
            run: "click",
        },
        {
            trigger:
                ".o-mail-DiscussSidebar:not(:has(.o-mail-DiscussSidebarChannel:contains(Accounting)))",
        },
    ],
});
